@@ -13,7 +13,7 @@ class Command(BaseCommand):
     Command class.
     """
     option_list = BaseCommand.option_list + (
-        make_option('--app-label',dest='app_label',help='The app label to which the local model belongs.')
+        make_option('--app-label',dest='app_label',help='The app label to which the local model belongs.'),
         make_option('--local-type',dest='local_type',help='The name of the local model'),
         make_option('--local-id',dest='local_id',help='The id of the local model'),
         make_option('--content-key',dest='content_key',help='The ACE content key to associate.'),
